==> agr-center-infrastructure-3.0.0-CLOUD-20221226.110131-1-sources.jar: com/tydic/dyc/agr/repository/po/AgrAdjustCfgPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 描述：agr_adjust_cfg
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class AgrAdjustCfgPO implements Serializable {
	private static final long serialVersionUID =  -2417988453037328968L;

	/**
	 * 调价配置ID
	 */
	private Long adjustCfgId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 是否存在加价项
	 */
	private Integer whetherAddPrice;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer whetherAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Integer whetherModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private Long adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private String adjustPriceFormula;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-infrastructure-3.1.1.0-CLOUD-20230106.111323-2-sources.jar: com/tydic/dyc/agr/repository/po/AgrAdjustCfgPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 描述：agr_adjust_cfg
 * 
 * @author auto_gen
 * @date 2022-11-22 10:31
 **/
@Data
public class AgrAdjustCfgPO implements Serializable {
	private static final long serialVersionUID =  171392329012616550L;

	/**
	 * 调价配置ID
	 */
	private Long adjustCfgId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 是否存在加价项
	 */
	private Integer whetherAddPrice;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer whetherAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Integer whetherModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private Long adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private String adjustPriceFormula;
	/**
	 * 创建者ID
	 */
	private Long createLoginId;
	/**
	 * 创建人
	 */
	private String createName;
	/**
	 * 创建人用户名
	 */
	private String createUsername;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 排序
	 */
	private String orderBy;

}
